diff --git a/AUTHORS.md b/AUTHORS.md
index 2e1a7224ebfc3420fc7e4263d50e020cb706cb63..9be14d021099a78c4adee826e1aedca69d008314 100644
--- a/AUTHORS.md
+++ b/AUTHORS.md
@@ -43,6 +43,7 @@ Kaylee de Soto
 Khun Sang Phukon
 Kruthi Krishna
 Kshipraa Athar
+Kyle Wong
 Leslie Wade
 Liting Xiao
 Maite Mateu-Lucena
diff --git a/examples/gw_examples/injection_examples/binary_neutron_star_example.py b/examples/gw_examples/injection_examples/binary_neutron_star_example.py
index e9c1bb70ad687b953d7c1ebe488623f296917265..bba394bcf01c42fefa400f72d80704fbec9f8575 100644
--- a/examples/gw_examples/injection_examples/binary_neutron_star_example.py
+++ b/examples/gw_examples/injection_examples/binary_neutron_star_example.py
@@ -78,7 +78,7 @@ interferometers.inject_signal(
 
 # Load the default prior for binary neutron stars.
 # We're going to sample in chirp_mass, symmetric_mass_ratio, lambda_tilde, and
 # delta_lambda rather than mass_1, mass_2, lambda_1, and lambda_2.
 # BNS have aligned spins by default, if you want to allow precessing spins
 # pass aligned_spin=False to the BNSPriorDict
 priors = bilby.gw.prior.BNSPriorDict()
@@ -102,8 +102,9 @@ priors["symmetric_mass_ratio"] = bilby.core.prior.Uniform(
     0.1, 0.25, name="symmetric_mass_ratio"
 )
 priors["lambda_tilde"] = bilby.core.prior.Uniform(0, 5000, name="lambda_tilde")
-priors["delta_lambda"] = bilby.core.prior.Uniform(-500, 1000, name="delta_lambda")
-
+priors["delta_lambda_tilde"] = bilby.core.prior.Uniform(
+    -500, 1000, name="delta_lambda_tilde"
+)
 priors["lambda_1"] = bilby.core.prior.Constraint(
     name="lambda_1", minimum=0, maximum=10000
 )
@@ -78,7 +78,7 @@ interferometers.inject_signal(
 # Load the default prior for binary neutron stars.
 # We're going to sample in chirp_mass, symmetric_mass_ratio, lambda_tilde, and
-# delta_lambda rather than mass_1, mass_2, lambda_1, and lambda_2.
+# delta_lambda_tilde rather than mass_1, mass_2, lambda_1, and lambda_2.
 # BNS have aligned spins by default, if you want to allow precessing spins
 # pass aligned_spin=False to the BNSPriorDict